==> jc-1.4.0.tar.gz: java/io/FilterReader.h <==
// public abstract class java.io.FilterReader

// class file dependencies
// @dep_class cd1b0cd67de1a4a8 java_io_FilterReader
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_Reader

#include "java/io/Reader.h"

#ifndef _JC_java_io_FilterReader_H_
#define _JC_java_io_FilterReader_H_

// Forward structure declarations
struct _jc_java_io_Reader$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_FilterReader$sub_refs	_jc_java_io_FilterReader$sub_refs;
typedef struct _jc_java_io_FilterReader$sub_nonrefs	_jc_java_io_FilterReader$sub_nonrefs;
typedef struct _jc_java_io_FilterReader$refs	_jc_java_io_FilterReader$refs;
typedef struct _jc_java_io_FilterReader$nonrefs	_jc_java_io_FilterReader$nonrefs;
typedef struct _jc_java_io_FilterReader$object	_jc_java_io_FilterReader$object;

typedef const struct _jc_java_io_FilterReader$vmethods	_jc_java_io_FilterReader$vmethods;
typedef const struct _jc_java_io_FilterReader$vtable	_jc_java_io_FilterReader$vtable;
typedef const struct _jc_java_io_FilterReader$vtype	_jc_java_io_FilterReader$vtype;

// Constructors
extern void _jc_java_io_FilterReader$method$_init$cc321c4706192fe8(_jc_env *, struct _jc_java_io_FilterReader$object *, struct _jc_java_io_Reader$object *);

// Virtual methods
extern void _jc_java_io_FilterReader$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_FilterReader$object *);
extern void _jc_java_io_FilterReader$method$mark$422af117ab27d9db(_jc_env *, struct _jc_java_io_FilterReader$object *, jint);
extern jboolean _jc_java_io_FilterReader$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_java_io_FilterReader$object *);
extern jint _jc_java_io_FilterReader$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_FilterReader$object *);
extern jint _jc_java_io_FilterReader$method$read$146ad4b836c4a55b(_jc_env *, struct _jc_java_io_FilterReader$object *, struct _jc_char_array *, jint, jint);
extern jboolean _jc_java_io_FilterReader$method$ready$83ea616797d9c364(_jc_env *, struct _jc_java_io_FilterReader$object *);
extern void _jc_java_io_FilterReader$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_io_FilterReader$object *);
extern jlong _jc_java_io_FilterReader$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_io_FilterReader$object *, jlong);

// Virtual method descriptors
extern _jc_method _jc_java_io_FilterReader$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_FilterReader$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_java_io_FilterReader$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_java_io_FilterReader$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_FilterReader$method_info$read$146ad4b836c4a55b;
extern _jc_method _jc_java_io_FilterReader$method_info$ready$83ea616797d9c364;
extern _jc_method _jc_java_io_FilterReader$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_io_FilterReader$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_java_io_FilterReader$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_FilterReader$object *);
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_java_io_FilterReader$object *, jint);
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_java_io_FilterReader$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_FilterReader$object *);
	jint	(*read$146ad4b836c4a55b)(_jc_env *, struct _jc_java_io_FilterReader$object *, struct _jc_char_array *, jint, jint);
	jboolean	(*ready$83ea616797d9c364)(_jc_env *, struct _jc_java_io_FilterReader$object *);
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_io_FilterReader$object *);
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_io_FilterReader$object *, jlong);
};

// Vtable
struct _jc_java_io_FilterReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_java_io_FilterReader$vmethods	java_io_FilterReader;
};

// Vtype
struct _jc_java_io_FilterReader$vtype {
	_jc_type			type;
	_jc_java_io_FilterReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FilterReader$sub_refs {
	struct _jc_java_io_Reader$object	*in;
};

// Reference instance fields (object)
struct _jc_java_io_FilterReader$refs {
    _jc_java_io_FilterReader$sub_refs	java_io_FilterReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FilterReader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_FilterReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_java_io_FilterReader$sub_nonrefs	java_io_FilterReader;
};

// Object instance structure
struct _jc_java_io_FilterReader$object {
	_jc_java_io_FilterReader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FilterReader$vtype	*vtype;
	_jc_java_io_FilterReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FilterReader$vtype _jc_java_io_FilterReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FilterReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FilterReader$class_object;

#endif	/* _JC_java_io_FilterReader_H_ */

==> jc-1.4.6.tar.gz: java/io/FilterReader.h <==
// public abstract class java.io.FilterReader

// class file dependencies
// @dep_class cd1b0cd67de1a4a8 java_io_FilterReader
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_Reader

#include "java/io/Reader.h"

#ifndef _JC_java_io_FilterReader_H_
#define _JC_java_io_FilterReader_H_

// Forward structure declarations
struct _jc_java_io_Reader$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_FilterReader$sub_refs	_jc_java_io_FilterReader$sub_refs;
typedef struct _jc_java_io_FilterReader$sub_nonrefs	_jc_java_io_FilterReader$sub_nonrefs;
typedef struct _jc_java_io_FilterReader$refs	_jc_java_io_FilterReader$refs;
typedef struct _jc_java_io_FilterReader$nonrefs	_jc_java_io_FilterReader$nonrefs;
typedef struct _jc_java_io_FilterReader$object	_jc_java_io_FilterReader$object;

typedef const struct _jc_java_io_FilterReader$vmethods	_jc_java_io_FilterReader$vmethods;
typedef const struct _jc_java_io_FilterReader$vtable	_jc_java_io_FilterReader$vtable;
typedef const struct _jc_java_io_FilterReader$vtype	_jc_java_io_FilterReader$vtype;

// Constructors
extern void _jc_java_io_FilterReader$method$_init$cc321c4706192fe8(_jc_env *, struct _jc_java_io_FilterReader$object *, struct _jc_java_io_Reader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_FilterReader$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_FilterReader$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FilterReader$method$mark$422af117ab27d9db(_jc_env *, struct _jc_java_io_FilterReader$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_io_FilterReader$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_java_io_FilterReader$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_FilterReader$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_FilterReader$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_FilterReader$method$read$146ad4b836c4a55b(_jc_env *, struct _jc_java_io_FilterReader$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_io_FilterReader$method$ready$83ea616797d9c364(_jc_env *, struct _jc_java_io_FilterReader$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FilterReader$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_io_FilterReader$object *) _JC_JCNI_ATTR;
extern jlong _jc_java_io_FilterReader$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_io_FilterReader$object *, jlong) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_FilterReader$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_FilterReader$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_java_io_FilterReader$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_java_io_FilterReader$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_FilterReader$method_info$read$146ad4b836c4a55b;
extern _jc_method _jc_java_io_FilterReader$method_info$ready$83ea616797d9c364;
extern _jc_method _jc_java_io_FilterReader$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_io_FilterReader$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_java_io_FilterReader$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_FilterReader$object *) _JC_JCNI_ATTR;
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_java_io_FilterReader$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_java_io_FilterReader$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_FilterReader$object *) _JC_JCNI_ATTR;
	jint	(*read$146ad4b836c4a55b)(_jc_env *, struct _jc_java_io_FilterReader$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
	jboolean	(*ready$83ea616797d9c364)(_jc_env *, struct _jc_java_io_FilterReader$object *) _JC_JCNI_ATTR;
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_io_FilterReader$object *) _JC_JCNI_ATTR;
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_io_FilterReader$object *, jlong) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_FilterReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_java_io_FilterReader$vmethods	java_io_FilterReader;
};

// Vtype
struct _jc_java_io_FilterReader$vtype {
	_jc_type			type;
	_jc_java_io_FilterReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FilterReader$sub_refs {
	struct _jc_java_io_Reader$object	*in;
};

// Reference instance fields (object)
struct _jc_java_io_FilterReader$refs {
    _jc_java_io_FilterReader$sub_refs	java_io_FilterReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FilterReader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_FilterReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_java_io_FilterReader$sub_nonrefs	java_io_FilterReader;
};

// Object instance structure
struct _jc_java_io_FilterReader$object {
	_jc_java_io_FilterReader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FilterReader$vtype	*vtype;
	_jc_java_io_FilterReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FilterReader$vtype _jc_java_io_FilterReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FilterReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FilterReader$class_object;

#endif	/* _JC_java_io_FilterReader_H_ */
